@@ -33,7 +33,7 @@ class Field:
         "Label": 'dom',
         "List": "etype",
         "SegMap": "dom",
-        "KeyPoint": "dom",
+        "Keypoint": "dom",
     }
 
     def __init__(self, name, field_value=None, field_type=None, is_attr=None, param=None):
