@@ -124,4 +124,4 @@ class DetectionParse(BaseParse):
                 sample_struct.set_optional("annotations")
             return (object_struct, sample_struct), [self._class_domain, self._class_domain.parent_domain], sample_container
         else:
-            return (sample_struct), [], sample_container
+            return (sample_struct,), [], sample_container
