@@ -38,7 +38,7 @@ class KeyPoint2DParse(BaseParse):
                 num_points = category_info.get("num_points", 0)
                 if num_points == 0:
                     continue
-                domain_name = f"KeyPoint_{category_name}_ClassDom"
+                domain_name = FileIO.clean(f"KeyPoint_{category_name}_ClassDom")
                 points_names = category_info.get("point_names", None)
                 skeleton = category_info.get("skeleton", None)
 
@@ -55,7 +55,7 @@ class KeyPoint2DParse(BaseParse):
                         this_point_label.add_supercategory(this_label)
                         this_point_domain.add_label(this_point_label, ori_id=point_ind)
                 else:
-                    for point_ind in range(1, num_points+1):
+                    for point_ind in range(1, num_points + 1):
                         this_point_label = Label(f"point_{point_ind}")
                         this_point_label.add_supercategory(this_label)
                         this_point_domain.add_label(this_point_label, ori_id=point_ind)
@@ -69,7 +69,7 @@ class KeyPoint2DParse(BaseParse):
         sample_struct.add_field(media_field)  # 添加图像field
         sample_container = DataSample(sample_struct, None)  # 暂时不添加 class domain
         domain_info = {}  # true_task_uid: domain
-        parent_domain_info = {} # true_task_uid: parent_domain
+        parent_domain_info = {}  # true_task_uid: parent_domain
         field_args = {}  # true_task_uid: arg
         for sample in tqdm(samples, desc="parsing samples ...."):
             sample_item = {}  # 存储当前样本信息
@@ -179,5 +179,6 @@ class KeyPoint2DParse(BaseParse):
             sample_struct.add_field(annotation_field)
             class_domains = list(domain_info.values())
             parent_class_domains = list(parent_domain_info.values())
-            return (object_struct, sample_struct), [self._parent_class_domain] + parent_class_domains + class_domains, sample_container
+            return (object_struct, sample_struct), [
+                self._parent_class_domain] + parent_class_domains + class_domains, sample_container
         return (sample_struct,), [], sample_container
